// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/src/core/utils/multi_color.dart';
import 'package:wyatt_ui_components/src/domain/theme_extensions/theme_extensions.dart';

/// {@template card_theme_extension_default}
/// Default card theme extension using Flutter's default card theme and
/// opinionated defaults.
/// {@endtemplate}
class CardThemeExtensionDefault extends CardThemeExtension {
  /// {@macro card_theme_extension_default}
  const CardThemeExtensionDefault({
    required super.radius,
    required super.padding,
    required super.backgroundColors,
    required super.borderColors,
    required super.stroke,
    required super.shadow,
    required super.minSize,
    required super.maxSize,
    required super.titleStyle,
    required super.subtitleStyle,
    required super.bodyStyle,
  });

  /// Creates a [CardThemeExtensionDefault] from a [ThemeData]
  /// and opinionated defaults.
  ///
  /// {@macro card_theme_extension_default}
  factory CardThemeExtensionDefault.from(ThemeData theme) =>
      CardThemeExtensionDefault(
        radius: const BorderRadius.all(Radius.circular(12)),
        padding: theme.cardTheme.margin ?? const EdgeInsets.all(15),
        backgroundColors: MultiColor.single(theme.cardColor),
        borderColors: MultiColor.single(theme.canvasColor),
        minSize: const Size(330, 0),
        maxSize: const Size(390, double.infinity),
        titleStyle: theme.textTheme.titleLarge,
        subtitleStyle: theme.textTheme.titleMedium,
        bodyStyle: theme.textTheme.bodyMedium,
        stroke: 0,
        shadow: null,
      );

  /// Creates a [CardThemeExtensionDefault] from a dark [ThemeData]
  factory CardThemeExtensionDefault.dark() =>
      CardThemeExtensionDefault.from(ThemeData.dark());

  /// Creates a [CardThemeExtensionDefault] from a light [ThemeData]
  factory CardThemeExtensionDefault.light() =>
      CardThemeExtensionDefault.from(ThemeData.light());
}
